# o2tuner
![](https://github.com/mconcas/o2tuner/actions/workflows/pythonpackage.yml/badge.svg)
![](https://github.com/mconcas/o2tuner/actions/workflows/codeql.yml/badge.svg)
![](https://github.com/mconcas/o2tuner/actions/workflows/pythonpublish.yml/badge.svg)

This package contains a tool for optimizing routines included in [ALICE O2](https://github.com/AliceO2Group/AliceO2)
